==> osidb_bindings-4.6.1.tar.gz: osidb_bindings-4.6.1/osidb_bindings/bindings/python_client/api/osidb/osidb_api_v1_flaws_acknowledgments_create.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.flaw_acknowledgment_post import FlawAcknowledgmentPost
from ...models.osidb_api_v1_flaws_acknowledgments_create_response_201 import (
    OsidbApiV1FlawsAcknowledgmentsCreateResponse201,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}

REQUEST_BODY_TYPE = FlawAcknowledgmentPost


def _get_kwargs(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
    ],
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/flaws/{flaw_id}/acknowledgments".format(
            flaw_id=flaw_id,
        ),
    }

    if isinstance(body, FlawAcknowledgmentPost):
        _json_body: dict[str, Any] = UNSET
        if not isinstance(body, Unset):
            _json_body = body.to_dict()

        _kwargs["json"] = _json_body
        headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    if response.status_code == 201:
        # }
        _response_201 = response.json()
        response_201: OsidbApiV1FlawsAcknowledgmentsCreateResponse201
        if isinstance(_response_201, Unset):
            response_201 = UNSET
        else:
            response_201 = OsidbApiV1FlawsAcknowledgmentsCreateResponse201.from_dict(
                _response_201
            )

        return response_201


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
    ],
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        client=client,
        body=body,
    )

    response = requests.post(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
    ],
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsAcknowledgmentsCreateResponse201
    """

    return sync_detailed(
        flaw_id=flaw_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
    ],
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        client=client,
        body=body,
    )

    async with client.get_async_session().post(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
        FlawAcknowledgmentPost,
    ],
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPost): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsAcknowledgmentsCreateResponse201
    """

    return (
        await asyncio_detailed(
            flaw_id=flaw_id,
            client=client,
            body=body,
        )
    ).parsed

==> osidb_bindings-4.11.0.tar.gz: osidb_bindings-4.11.0/osidb_bindings/bindings/python_client/api/osidb/osidb_api_v1_flaws_acknowledgments_create.py <==
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.flaw_acknowledgment_post_request import FlawAcknowledgmentPostRequest
from ...models.osidb_api_v1_flaws_acknowledgments_create_response_201 import (
    OsidbApiV1FlawsAcknowledgmentsCreateResponse201,
)
from ...types import UNSET, Response, Unset, check_nested_instance

QUERY_PARAMS = {}

REQUEST_BODY_TYPE = FlawAcknowledgmentPostRequest


def _get_kwargs(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
    ],
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/flaws/{flaw_id}/acknowledgments".format(
            flaw_id=flaw_id,
        ),
    }

    if check_nested_instance(body, FlawAcknowledgmentPostRequest):
        _json_body: dict[str, Any] = UNSET
        if not isinstance(body, Unset):
            _json_body = body.to_dict()

        _kwargs["json"] = _json_body
        headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    if response.status_code == 201:
        _response_201 = response.json()
        response_201: OsidbApiV1FlawsAcknowledgmentsCreateResponse201
        if isinstance(_response_201, Unset):
            response_201 = UNSET
        else:
            response_201 = OsidbApiV1FlawsAcknowledgmentsCreateResponse201.from_dict(
                _response_201
            )

        return response_201


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
    ],
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        client=client,
        body=body,
    )

    response = requests.post(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
    ],
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsAcknowledgmentsCreateResponse201
    """

    return sync_detailed(
        flaw_id=flaw_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
    ],
) -> Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        client=client,
        body=body,
    )

    async with client.get_async_session().post(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    flaw_id: UUID,
    *,
    client: AuthenticatedClient,
    body: Union[
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
        FlawAcknowledgmentPostRequest,
    ],
) -> Optional[OsidbApiV1FlawsAcknowledgmentsCreateResponse201]:
    """
    Args:
        flaw_id (UUID):
        bugzilla_api_key (str):
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer
        body (FlawAcknowledgmentPostRequest): FlawAcknowledgment serializer

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsAcknowledgmentsCreateResponse201
    """

    return (
        await asyncio_detailed(
            flaw_id=flaw_id,
            client=client,
            body=body,
        )
    ).parsed
